# inkpot
a small simple library for generating documentation from docstrings

is available on [pip](https://pypi.org/project/cira/). **Please give it a star if you like it!**

<img src="https://cdn.pixabay.com/photo/2014/04/05/12/20/ink-316909_960_720.jpg" alt="drawing" width="300"/>

![GitHub stars](https://img.shields.io/github/stars/AxelGard/inkpot?style=social)
![GitHub forks](https://img.shields.io/github/forks/AxelGard/inkpot?style=social)
[![Tweet](https://img.shields.io/twitter/url/http/shields.io.svg?style=social)](https://twitter.com/Axel_Gard)

![GitHub](https://img.shields.io/github/license/AxelGard/inkpot?style=plastic)
![PyPI](https://img.shields.io/pypi/v/inkpot)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/inkpot)
![PyPI - Downloads](https://img.shields.io/pypi/dm/inkpot)



## Installation
```bash
pip install inkpot
```

## Usage
```bash
python3 -m inkpot myfile.py
```
or to a file 
```bash
python3 -m inkpot myfile.py > doc.md
```

## License
This project is licensed under the MIT License - see the [LICENSE](LICENSE.txt) file for details
